pub struct NestedPath(/* private fields */);Expand description
Access the path the matched the route is nested at.
This can for example be used when doing redirects.
Example
use axum::{
Router,
extract::NestedPath,
routing::get,
};
let api = Router::new().route(
"/users",
get(|path: NestedPath| async move {
// `path` will be "/api" because that's what this
// router is nested at when we build `app`
let path = path.as_str();
})
);
let app = Router::new().nest("/api", api);Implementations