pub struct HandlerService<H, T, S> { /* private fields */ }Expand description
An adapter that makes a Handler into a Service.
Created with Handler::with_state or HandlerWithoutStateExt::into_service.
Implementations
Sourceimpl<H, T, S> HandlerService<H, T, S>
impl<H, T, S> HandlerService<H, T, S>
Sourcepub fn into_make_service(self) -> IntoMakeService<HandlerService<H, T, S>>
pub fn into_make_service(self) -> IntoMakeService<HandlerService<H, T, S>>
Convert the handler into a MakeService.
This allows you to serve a single handler if you don’t need any routing:
use axum::{
handler::Handler,
extract::State,
http::{Uri, Method},
response::IntoResponse,
};
use std::net::SocketAddr;
#[derive(Clone)]
struct AppState {}
async fn handler(State(state): State<AppState>) {
// ...
}
let app = handler.with_state(AppState {});
let listener = tokio::net::TcpListener::bind("0.0.0.0:3000").await.unwrap();
axum::serve(listener, app.into_make_service()).await.unwrap();Sourcepub fn into_make_service_with_connect_info<C>(
self,
) -> IntoMakeServiceWithConnectInfo<HandlerService<H, T, S>, C>
pub fn into_make_service_with_connect_info<C>( self, ) -> IntoMakeServiceWithConnectInfo<HandlerService<H, T, S>, C>
Convert the handler into a MakeService which stores information
about the incoming connection.
See Router::into_make_service_with_connect_info for more details.
use axum::{
handler::Handler,
response::IntoResponse,
extract::{ConnectInfo, State},
};
use std::net::SocketAddr;
#[derive(Clone)]
struct AppState {};
async fn handler(
ConnectInfo(addr): ConnectInfo<SocketAddr>,
State(state): State<AppState>,
) -> String {
format!("Hello {addr}")
}
let app = handler.with_state(AppState {});
let listener = tokio::net::TcpListener::bind("0.0.0.0:3000").await.unwrap();
axum::serve(
listener,
app.into_make_service_with_connect_info::<SocketAddr>(),
).await.unwrap();Trait Implementations
Sourceimpl<H, T, S> Clone for HandlerService<H, T, S>
impl<H, T, S> Clone for HandlerService<H, T, S>
Sourcefn clone(&self) -> HandlerService<H, T, S>
fn clone(&self) -> HandlerService<H, T, S>
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<H, T, S> Debug for HandlerService<H, T, S>
impl<H, T, S> Debug for HandlerService<H, T, S>
Sourceimpl<H, T, S, L> Service<IncomingStream<'_, L>> for HandlerService<H, T, S>
impl<H, T, S, L> Service<IncomingStream<'_, L>> for HandlerService<H, T, S>
Sourcetype Response = HandlerService<H, T, S>
type Response = HandlerService<H, T, S>
Sourcetype Error = Infallible
type Error = Infallible
Sourcetype Future = Ready<Result<<HandlerService<H, T, S> as Service<IncomingStream<'_, L>>>::Response, <HandlerService<H, T, S> as Service<IncomingStream<'_, L>>>::Error>>
type Future = Ready<Result<<HandlerService<H, T, S> as Service<IncomingStream<'_, L>>>::Response, <HandlerService<H, T, S> as Service<IncomingStream<'_, L>>>::Error>>
Sourcefn poll_ready(
&mut self,
_cx: &mut Context<'_>,
) -> Poll<Result<(), <HandlerService<H, T, S> as Service<IncomingStream<'_, L>>>::Error>>
fn poll_ready( &mut self, _cx: &mut Context<'_>, ) -> Poll<Result<(), <HandlerService<H, T, S> as Service<IncomingStream<'_, L>>>::Error>>
Poll::Ready(Ok(())) when the service is able to process requests. Read moreSourcefn call(
&mut self,
_req: IncomingStream<'_, L>,
) -> <HandlerService<H, T, S> as Service<IncomingStream<'_, L>>>::Future
fn call( &mut self, _req: IncomingStream<'_, L>, ) -> <HandlerService<H, T, S> as Service<IncomingStream<'_, L>>>::Future
Sourceimpl<H, T, S, B> Service<Request<B>> for HandlerService<H, T, S>
impl<H, T, S, B> Service<Request<B>> for HandlerService<H, T, S>