parse_index_attribute

Function parse_index_attribute 

pub fn parse_index_attribute(raw: &str) -> Result<ParsedIndexAttribute, String>
Parses @@index([field1, field2, ...]), optionally followed by using: <method> and/or opclass: "<name>". Callers are responsible for checking that each field name resolves to a real scalar field on the model.